@@ -287,14 +287,10 @@ pub type NcEgcBackstop = u8;
 /// - [`NCSTYLE_UNDERCURL`]
 /// - [`NCSTYLE_STRUCK`]
 /// - [`NCSTYLE_ITALIC`]
-/// - [`NCSTYLE_STANDOUT`]
 /// - [`NCSTYLE_UNDERLINE`]
 /// - [`NCSTYLE_REVERSE`]
-/// - [`NCSTYLE_BLINK`]
 /// - [`NCSTYLE_DIM`]
 /// - [`NCSTYLE_BOLD`]
-/// - [`NCSTYLE_INVIS`]
-/// - [`NCSTYLE_PROTECT`]
 /// - [`NCSTYLE_NONE`]
 ///
 /// ## Diagram
@@ -319,29 +315,17 @@ pub const NCSTYLE_STRUCK: u16 = crate::bindings::ffi::NCSTYLE_STRUCK as u16;
 ///
 pub const NCSTYLE_ITALIC: u16 = crate::bindings::ffi::NCSTYLE_ITALIC as u16;
 
-///
-pub const NCSTYLE_STANDOUT: u16 = crate::bindings::ffi::NCSTYLE_STANDOUT as u16;
-
 ///
 pub const NCSTYLE_UNDERLINE: u16 = crate::bindings::ffi::NCSTYLE_UNDERLINE as u16;
 
 ///
 pub const NCSTYLE_REVERSE: u16 = crate::bindings::ffi::NCSTYLE_REVERSE as u16;
 
-///
-pub const NCSTYLE_BLINK: u16 = crate::bindings::ffi::NCSTYLE_BLINK as u16;
-
 ///
 pub const NCSTYLE_DIM: u16 = crate::bindings::ffi::NCSTYLE_DIM as u16;
 
 ///
 pub const NCSTYLE_BOLD: u16 = crate::bindings::ffi::NCSTYLE_BOLD as u16;
 
-///
-pub const NCSTYLE_INVIS: u16 = crate::bindings::ffi::NCSTYLE_INVIS as u16;
-
-///
-pub const NCSTYLE_PROTECT: u16 = crate::bindings::ffi::NCSTYLE_PROTECT as u16;
-
 ///
 pub const NCSTYLE_NONE: u16 = crate::bindings::ffi::NCSTYLE_NONE as u16;
