@@ -3,15 +3,15 @@
 use libc::strcmp;
 
 use crate::{
-    cstring, nccell_release, NcAlphaBits, NcCell, NcChannel, NcChannelPair, NcColor, NcEgc,
-    NcIntResult, NcPaletteIndex, NcPlane, NcRgb, NcStyleMask, NCCELL_ALPHA_OPAQUE,
-    NCCELL_BGDEFAULT_MASK, NCCELL_BG_PALETTE, NCCELL_FGDEFAULT_MASK, NCCELL_FG_PALETTE,
-    NCRESULT_ERR, NCRESULT_OK, NCSTYLE_MASK,
+    cstring, nccell_release, NcAlphaBits, NcCell, NcChannel, NcChannels, NcComponent, NcEgc,
+    NcIntResult, NcPaletteIndex, NcPlane, NcRgb, NcStyle, NCALPHA_BGDEFAULT_MASK,
+    NCALPHA_BG_PALETTE, NCALPHA_FGDEFAULT_MASK, NCALPHA_FG_PALETTE, NCALPHA_OPAQUE, NCRESULT_ERR,
+    NCRESULT_OK, NCSTYLE_MASK,
 };
 
 // Alpha -----------------------------------------------------------------------
 
-/// Extracts the foreground [NcAlphaBits] from an [NcCell] (shifted to LSBs).
+/// Extracts the foreground [`NcAlphaBits`] from an [`NcCell`] (shifted to LSBs).
 ///
 /// *Method: NcCell.[fg_alpha()][NcCell#method.fg_alpha].*
 #[inline]
@@ -19,7 +19,7 @@ pub fn nccell_fg_alpha(cell: &NcCell) -> NcAlphaBits {
     crate::ncchannels_fg_alpha(cell.channels)
 }
 
-/// Extracts the background [NcAlphaBits] from an [NcCell] (shifted to LSBs).
+/// Extracts the background [`NcAlphaBits`] from an [`NcCell`] (shifted to LSBs).
 ///
 /// *Method: NcCell.[bg_alpha()][NcCell#method.bg_alpha].*
 #[inline]
@@ -27,7 +27,7 @@ pub fn nccell_bg_alpha(cell: &NcCell) -> NcAlphaBits {
     crate::ncchannels_bg_alpha(cell.channels)
 }
 
-/// Sets the foreground [NcAlphaBits] of an [NcCell].
+/// Sets the foreground [`NcAlphaBits`] of an [`NcCell`].
 ///
 /// *Method: NcCell.[set_fg_alpha()][NcCell#method.set_fg_alpha].*
 #[inline]
@@ -35,7 +35,7 @@ pub fn nccell_set_fg_alpha(cell: &mut NcCell, alpha: NcAlphaBits) {
     crate::ncchannels_set_fg_alpha(&mut cell.channels, alpha);
 }
 
-/// Sets the background [NcAlphaBits] of an [NcCell].
+/// Sets the background [`NcAlphaBits`] of an [`NcCell`].
 ///
 /// *Method: NcCell.[set_bg_alpha()][NcCell#method.set_bg_alpha].*
 #[inline]
@@ -43,57 +43,67 @@ pub fn nccell_set_bg_alpha(cell: &mut NcCell, alpha: NcAlphaBits) {
     crate::ncchannels_set_bg_alpha(&mut cell.channels, alpha);
 }
 
-// NcColor ---------------------------------------------------------------------
+// NcComponent ---------------------------------------------------------------------
 
-/// Gets the foreground [NcColor] RGB components of an [NcCell],
-/// and returns the [NcChannel] (which can have some extra bits set).
+/// Gets the foreground [`NcComponent`]s of an [`NcCell`],
+/// and returns the [`NcChannel`] (which can have some extra bits set).
 ///
 /// *Method: NcCell.[fg_rgb8()][NcCell#method.fg_rgb8].*
 #[inline]
 pub fn nccell_fg_rgb8(
     cell: &NcCell,
-    red: &mut NcColor,
-    green: &mut NcColor,
-    blue: &mut NcColor,
+    red: &mut NcComponent,
+    green: &mut NcComponent,
+    blue: &mut NcComponent,
 ) -> NcChannel {
     crate::ncchannels_fg_rgb8(cell.channels, red, green, blue)
 }
 
-/// Gets the background [NcColor] RGB components of an [NcCell],
-/// and returns the [NcChannel] (which can have some extra bits set).
+/// Gets the background [`NcComponent`]s of an [`NcCell`],
+/// and returns the [`NcChannel`] (which can have some extra bits set).
 ///
 /// *Method: NcCell.[bg_rgb8()][NcCell#method.bg_rgb8].*
 #[inline]
 pub fn nccell_bg_rgb8(
     cell: &NcCell,
-    red: &mut NcColor,
-    green: &mut NcColor,
-    blue: &mut NcColor,
+    red: &mut NcComponent,
+    green: &mut NcComponent,
+    blue: &mut NcComponent,
 ) -> NcChannel {
     crate::ncchannels_bg_rgb8(cell.channels, red, green, blue)
 }
 
-/// Sets the foreground [NcColor] RGB components of the [NcCell],
+/// Sets the foreground [`NcComponent`]s of the [`NcCell`],
 /// and marks it as not using the "default color".
 ///
 /// *Method: NcCell.[set_fg_rgb8()][NcCell#method.set_fg_rgb8].*
 #[inline]
-pub fn nccell_set_fg_rgb8(cell: &mut NcCell, red: NcColor, green: NcColor, blue: NcColor) {
+pub fn nccell_set_fg_rgb8(
+    cell: &mut NcCell,
+    red: NcComponent,
+    green: NcComponent,
+    blue: NcComponent,
+) {
     crate::ncchannels_set_fg_rgb8(&mut cell.channels, red, green, blue);
 }
 
-/// Sets the background [NcColor] RGB components of the [NcCell],
+/// Sets the background [`NcComponent`]s of the [`NcCell`],
 /// and marks it as not using the "default color".
 ///
 /// *Method: NcCell.[set_bg_rgb8()][NcCell#method.set_bg_rgb8].*
 #[inline]
-pub fn nccell_set_bg_rgb8(cell: &mut NcCell, red: NcColor, green: NcColor, blue: NcColor) {
+pub fn nccell_set_bg_rgb8(
+    cell: &mut NcCell,
+    red: NcComponent,
+    green: NcComponent,
+    blue: NcComponent,
+) {
     crate::ncchannels_set_bg_rgb8(&mut cell.channels, red, green, blue);
 }
 
 // NcRgb -----------------------------------------------------------------------
 
-/// Gets the foreground [NcRgb] from an [NcCell] (shifted to LSBs).
+/// Gets the foreground [`NcRgb`] from an [`NcCell`] (shifted to LSBs).
 ///
 /// *Method: NcCell.[fg_rgb()][NcCell#method.fg_rgb].*
 #[inline]
@@ -101,7 +111,7 @@ pub fn nccell_fg_rgb(cell: &NcCell) -> NcRgb {
     crate::ncchannels_fg_rgb(cell.channels)
 }
 
-/// Gets the background [NcRgb] from an [NcCell] (shifted to LSBs).
+/// Gets the background [`NcRgb`] from an [`NcCell`] (shifted to LSBs).
 ///
 /// *Method: NcCell.[bg_rgb()][NcCell#method.bg_rgb].*
 #[inline]
@@ -109,7 +119,7 @@ pub fn nccell_bg_rgb(cell: &NcCell) -> NcRgb {
     crate::ncchannels_bg_rgb(cell.channels)
 }
 
-/// Sets the foreground [NcRgb] of an [NcCell],
+/// Sets the foreground [`NcRgb`] of an [`NcCell`],
 /// and marks it as not using the default color.
 ///
 /// *Method: NcCell.[set_fg_rgb()][NcCell#method.set_fg_rgb].*
@@ -118,7 +128,7 @@ pub fn nccell_set_fg_rgb(cell: &mut NcCell, rgb: NcRgb) {
     crate::ncchannels_set_fg_rgb(&mut cell.channels, rgb);
 }
 
-/// Sets the background [NcRgb] of an [NcCell],
+/// Sets the background [`NcRgb`] of an [`NcCell`],
 /// and marks it as not using the default color.
 ///
 /// *Method: NcCell.[set_bg_rgb()][NcCell#method.set_bg_rgb].*
@@ -129,8 +139,8 @@ pub fn nccell_set_bg_rgb(cell: &mut NcCell, rgb: NcRgb) {
 
 // Default ---------------------------------------------------------------------
 
-/// Indicates to use the "default color" for the foreground [NcChannel]
-/// of an [NcCell].
+/// Indicates to use the "default color" for the foreground [`NcChannel`]
+/// of an [`NcCell`].
 ///
 /// *Method: NcCell.[set_fg_default()][NcCell#method.set_fg_default].*
 #[inline]
@@ -138,8 +148,8 @@ pub fn nccell_set_fg_default(cell: &mut NcCell) {
     crate::ncchannels_set_fg_default(&mut cell.channels);
 }
 
-/// Indicates to use the "default color" for the background [NcChannel]
-/// of an [NcCell].
+/// Indicates to use the "default color" for the background [`NcChannel`]
+/// of an [`NcCell`].
 ///
 /// *Method: NcCell.[set_bg_default()][NcCell#method.set_bg_default].*
 #[inline]
@@ -147,7 +157,7 @@ pub fn nccell_set_bg_default(cell: &mut NcCell) {
     crate::ncchannels_set_bg_default(&mut cell.channels);
 }
 
-/// Is the foreground [NcChannel] of this [NcCell] using the
+/// Is the foreground [`NcChannel`] of this [`NcCell`] using the
 /// "default foreground color"?
 ///
 /// *Method: NcCell.[fg_default_p()][NcCell#method.fg_default_p].*
@@ -156,7 +166,7 @@ pub fn nccell_fg_default_p(cell: &NcCell) -> bool {
     crate::ncchannels_fg_default_p(cell.channels)
 }
 
-/// Is the background [NcChannel] of this [NcCell] using the
+/// Is the background [`NcChannel`] of this [`NcCell`] using the
 /// "default background color"?
 ///
 /// The "default background color" must generally be used to take advantage of
@@ -170,8 +180,8 @@ pub fn nccell_bg_default_p(cell: &NcCell) -> bool {
 
 // Palette ---------------------------------------------------------------------
 
-/// Is the foreground [NcChannel] of this [NcCell] using an
-/// [NcPaletteIndex] [indexed][NcPaletteIndex] [NcPalette][crate::NcPalette] color?
+/// Is the foreground [`NcChannel`] of this [`NcCell`] using an
+/// [`NcPaletteIndex`] indexed [`NcPalette`][crate::NcPalette] color?
 ///
 /// *Method: NcCell.[fg_palindex_p()][NcCell#method.fg_palindex_p].*
 #[inline]
@@ -179,8 +189,8 @@ pub fn nccell_fg_palindex_p(cell: &NcCell) -> bool {
     crate::ncchannels_fg_palindex_p(cell.channels)
 }
 
-/// Is the background [NcChannel] of this [NcCell] using an
-/// [NcPaletteIndex] [indexed][NcPaletteIndex] [NcPalette][crate::NcPalette] color?
+/// Is the background [`NcChannel`] of this [`NcCell`] using an
+/// [`NcPaletteIndex`] indexed [`NcPalette`][crate::NcPalette] color?
 ///
 /// *Method: NcCell.[bg_palindex_p()][NcCell#method.bg_palindex_p].*
 #[inline]
@@ -188,16 +198,16 @@ pub fn nccell_bg_palindex_p(cell: &NcCell) -> bool {
     crate::ncchannels_bg_palindex_p(cell.channels)
 }
 
-/// Gets the [NcPaletteIndex] of the foreground [NcChannel] of the [NcCell].
+/// Gets the [`NcPaletteIndex`] of the foreground [`NcChannel`] of the [`NcCell`].
 ///
 /// *Method: NcCell.[fg_palindex()][NcCell#method.fg_palindex].*
 #[inline]
 #[allow(clippy::unnecessary_cast)]
 pub const fn nccell_fg_palindex(cell: &NcCell) -> NcPaletteIndex {
-    ((cell.channels & 0xff00000000 as NcChannelPair) >> 32) as NcPaletteIndex
+    ((cell.channels & 0xff00000000 as NcChannels) >> 32) as NcPaletteIndex
 }
 
-/// Gets the [NcPaletteIndex] of the background [NcChannel] of the [NcCell].
+/// Gets the [`NcPaletteIndex`] of the background [`NcChannel`] of the [`NcCell`].
 ///
 /// *Method: NcCell.[bg_palindex()][NcCell#method.bg_palindex].*
 #[inline]
@@ -206,10 +216,10 @@ pub const fn nccell_bg_palindex(cell: &NcCell) -> NcPaletteIndex {
     (cell.channels & 0xff) as NcPaletteIndex
 }
 
-/// Sets an [NcCell]'s foreground [NcPaletteIndex].
+/// Sets an [`NcCell`]'s foreground [`NcPaletteIndex`].
 ///
-/// Also sets [NCCELL_FG_PALETTE] and [NCCELL_ALPHA_OPAQUE],
-/// and clears out [NCCELL_FGDEFAULT_MASK].
+/// Also sets [NCALPHA_FG_PALETTE] and [NCALPHA_OPAQUE],
+/// and clears out [NCALPHA_FGDEFAULT_MASK].
 ///
 /// *Method: NcCell.[set_fg_palindex()][NcCell#method.set_fg_palindex].*
 //
@@ -217,69 +227,69 @@ pub const fn nccell_bg_palindex(cell: &NcCell) -> NcPaletteIndex {
 #[inline]
 #[allow(clippy::unnecessary_cast)]
 pub fn nccell_set_fg_palindex(cell: &mut NcCell, index: NcPaletteIndex) {
-    cell.channels |= NCCELL_FGDEFAULT_MASK;
-    cell.channels |= NCCELL_FG_PALETTE;
-    nccell_set_fg_alpha(cell, NCCELL_ALPHA_OPAQUE);
-    cell.channels &= 0xff000000ffffffff as NcChannelPair;
-    cell.channels |= (index as NcChannelPair) << 32;
+    cell.channels |= NCALPHA_FGDEFAULT_MASK;
+    cell.channels |= NCALPHA_FG_PALETTE;
+    nccell_set_fg_alpha(cell, NCALPHA_OPAQUE);
+    cell.channels &= 0xff000000ffffffff as NcChannels;
+    cell.channels |= (index as NcChannels) << 32;
 }
 
-/// Sets an [NcCell]'s background [NcPaletteIndex].
+/// Sets an [`NcCell`]'s background [`NcPaletteIndex`].
 ///
-/// Also sets [NCCELL_BG_PALETTE] and [NCCELL_ALPHA_OPAQUE],
-/// and clears out [NCCELL_BGDEFAULT_MASK].
+/// Also sets [`NCALPHA_BG_PALETTE`] and [`NCALPHA_OPAQUE`],
+/// and clears out [`NCALPHA_BGDEFAULT_MASK`].
 ///
 /// *Method: NcCell.[set_bg_palindex()][NcCell#method.set_bg_palindex].*
 //
 // NOTE: unlike the original C function, this one can't fail
 #[inline]
 pub fn nccell_set_bg_palindex(cell: &mut NcCell, index: NcPaletteIndex) {
-    cell.channels |= NCCELL_BGDEFAULT_MASK as NcChannelPair;
-    cell.channels |= NCCELL_BG_PALETTE as NcChannelPair;
-    nccell_set_bg_alpha(cell, NCCELL_ALPHA_OPAQUE);
+    cell.channels |= NCALPHA_BGDEFAULT_MASK as NcChannels;
+    cell.channels |= NCALPHA_BG_PALETTE as NcChannels;
+    nccell_set_bg_alpha(cell, NCALPHA_OPAQUE);
     cell.channels &= 0xffffffffff000000;
-    cell.channels |= index as NcChannelPair;
+    cell.channels |= index as NcChannels;
 }
 
 // Styles ----------------------------------------------------------------------
 
-/// Extracts the [NcStyleMask] bits from an [NcCell].
+/// Extracts the [`NcStyle`] bits from an [`NcCell`].
 ///
 /// *Method: NcCell.[cell_styles()][NcCell#method.cell_styles].*
 #[inline]
-pub const fn nccell_styles(cell: &NcCell) -> NcStyleMask {
+pub const fn nccell_styles(cell: &NcCell) -> NcStyle {
     cell.stylemask
 }
 
-/// Adds the specified [NcStyleMask] bits to an [NcCell]'s existing spec.,
+/// Adds the specified [`NcStyle`] bits to an [`NcCell`]'s existing spec.,
 /// whether they're actively supported or not.
 ///
 /// *Method: NcCell.[styles_on()][NcCell#method.styles_on].*
 #[inline]
-pub fn nccell_on_styles(cell: &mut NcCell, stylebits: NcStyleMask) {
+pub fn nccell_on_styles(cell: &mut NcCell, stylebits: NcStyle) {
     cell.stylemask |= stylebits & NCSTYLE_MASK as u16;
 }
 
-/// Removes the specified [NcStyleMask] bits from an [NcCell]'s existing spec.
+/// Removes the specified [`NcStyle`] bits from an [`NcCell`]'s existing spec.
 ///
 /// *Method: NcCell.[styles_off()][NcCell#method.styles_off].*
 #[inline]
-pub fn nccell_off_styles(cell: &mut NcCell, stylebits: NcStyleMask) {
+pub fn nccell_off_styles(cell: &mut NcCell, stylebits: NcStyle) {
     cell.stylemask &= !(stylebits & NCSTYLE_MASK as u16);
 }
 
-/// Sets *just* the specified [NcStyleMask] bits for an [NcCell],
+/// Sets *just* the specified [`NcStyle`] bits for an [`NcCell`],
 /// whether they're actively supported or not.
 ///
 /// *Method: NcCell.[styles_set()][NcCell#method.styles_set].*
 #[inline]
-pub fn nccell_set_styles(cell: &mut NcCell, stylebits: NcStyleMask) {
+pub fn nccell_set_styles(cell: &mut NcCell, stylebits: NcStyle) {
     cell.stylemask = stylebits & NCSTYLE_MASK as u16;
 }
 
 // Chars -----------------------------------------------------------------------
 
-/// Does the [NcCell] contain an East Asian Wide codepoint?
+/// Does the [`NcCell`] contain an East Asian Wide codepoint?
 ///
 /// *Method: NcCell.[double_wide_p()][NcCell#method.double_wide_p].*
 #[inline]
@@ -303,7 +313,7 @@ pub const fn nccell_wide_left_p(cell: &NcCell) -> bool {
     nccell_double_wide_p(cell) && cell.gcluster != 0
 }
 
-// /// Loads a 7-bit [NcEgc] character into the [NcCell].
+// /// Loads a 7-bit [`NcEgc`] character into the [`NcCell`].
 // ///
 // /// *Method: NcCell.[load_char()][NcCell#method.load_char].*
 // //
@@ -344,7 +354,7 @@ pub const fn nccell_wide_left_p(cell: &NcCell) -> bool {
 //   return nccell_load(n, c, gcluster);
 // }
 
-/// Copies the UTF8-encoded [NcEgc] out of the [NcCell], whether simple or complex.
+/// Copies the UTF8-encoded [`NcEgc`] out of the [`NcCell`], whether simple or complex.
 ///
 /// The result is not tied to the [NcPlane],
 /// and persists across erases and destruction.
@@ -365,16 +375,16 @@ pub fn nccell_strdup(plane: &NcPlane, cell: &NcCell) -> NcEgc {
 
 // Misc. -----------------------------------------------------------------------
 
-/// Saves the [NcStyleMask] and the [NcChannelPair],
-/// and returns the [NcEgc], of an [NcCell].
+/// Saves the [`NcStyle`] and the [`NcChannels`],
+/// and returns the [`NcEgc`], of an [`NcCell`].
 ///
 /// *Method: NcCell.[extract()][NcCell#method.extract].*
 #[inline]
 pub fn nccell_extract(
     plane: &NcPlane,
     cell: &NcCell,
-    stylemask: &mut NcStyleMask,
-    channels: &mut NcChannelPair,
+    stylemask: &mut NcStyle,
+    channels: &mut NcChannels,
 ) -> NcEgc {
     if *stylemask != 0 {
         *stylemask = cell.stylemask;
@@ -385,7 +395,7 @@ pub fn nccell_extract(
     nccell_strdup(plane, cell)
 }
 
-/// Returns true if the two cells are distinct [NcEgc]s, attributes, or channels.
+/// Returns true if the two cells are distinct [`NcEgc`]s, attributes, or channels.
 ///
 /// The actual egcpool index needn't be the same--indeed, the planes needn't even
 /// be the same. Only the expanded NcEgc must be equal. The NcEgc must be bit-equal;
@@ -409,7 +419,7 @@ pub fn nccellcmp(plane1: &NcPlane, cell1: &NcCell, plane2: &NcPlane, cell2: &NcC
     }
 }
 
-/// Initializes (zeroes out) an [NcCell].
+/// Initializes (zeroes out) an [`NcCell`].
 ///
 /// *Method: NcCell.[init()][NcCell#method.init].*
 #[inline]
@@ -417,7 +427,7 @@ pub fn nccell_init(cell: &mut NcCell) {
     *cell = unsafe { core::mem::zeroed() }
 }
 
-/// Same as [nccell_load][crate::nccell_load], plus blasts the styling with
+/// Same as [`nccell_load`][crate::nccell_load], plus blasts the styling with
 /// `style` and `channels`.
 ///
 /// - Breaks the UTF-8 string in `gcluster` down, setting up the cell `cell`.
@@ -430,26 +440,26 @@ pub fn nccell_prime(
     plane: &mut NcPlane,
     cell: &mut NcCell,
     gcluster: &str,
-    style: NcStyleMask,
-    channels: NcChannelPair,
+    style: NcStyle,
+    channels: NcChannels,
 ) -> NcIntResult {
     cell.stylemask = style;
     cell.channels = channels;
     unsafe { crate::nccell_load(plane, cell, cstring![gcluster]) }
 }
 
-/// Loads up six cells with the [NcEgc]s necessary to draw a box.
+/// Loads up six cells with the [`NcEgc`]s necessary to draw a box.
 ///
-/// Returns [NCRESULT_OK] on success or [NCRESULT_ERR] on error.
+/// Returns [`NCRESULT_OK`] on success or [`NCRESULT_ERR`] on error.
 ///
-/// On error, any [NcCell]s this function might have loaded before the error
-/// are [nccell_release]d. There must be at least six [NcEgc]s in `gcluster`.
+/// On error, any [`NcCell`]s this function might have loaded before the error
+/// are [nccell_release]d. There must be at least six [`NcEgc`]s in `gcluster`.
 ///
 /// *Method: NcCell.[load_box()][NcCell#method.load_box].*
 pub fn nccells_load_box(
     plane: &mut NcPlane,
-    style: NcStyleMask,
-    channels: NcChannelPair,
+    style: NcStyle,
+    channels: NcChannels,
     ul: &mut NcCell,
     ur: &mut NcCell,
     ll: &mut NcCell,
